@@ -1,10 +1,12 @@
 use anyhow::{Error, Result};
-use bdk::{blockchain::esplora::EsploraBlockchain, database::MemoryDatabase, SignOptions, Wallet};
+use bdk::{blockchain::Blockchain, database::MemoryDatabase, SignOptions, Wallet};
 use bitcoin::{consensus::serialize, util::psbt::PartiallySignedTransaction};
 use gloo_console::log;
 
+use crate::operations::bitcoin::balance::get_blockchain;
+
 pub async fn sign_psbt(
-    wallet: &Wallet<EsploraBlockchain, MemoryDatabase>,
+    wallet: &Wallet<MemoryDatabase>,
     mut psbt: PartiallySignedTransaction,
 ) -> Result<()> {
     let finalized = wallet.sign(&mut psbt, SignOptions::default())?;
@@ -12,7 +14,8 @@ pub async fn sign_psbt(
         log!("Signed PSBT: {}", base64::encode(&serialize(&psbt)));
         let tx = psbt.extract_tx();
         log!("tx: {}", base64::encode(&serialize(&tx)));
-        wallet.broadcast(&tx).await?;
+        let blockchain = get_blockchain();
+        blockchain.broadcast(&tx).await?;
         Ok(())
     } else {
         Err(Error::msg(""))
