@@ -9,5 +9,5 @@ pub use accept_transaction::accept_transfer;
 pub use create_psbt::create_psbt;
 pub use import_asset::{get_asset, get_assets};
 pub use receive_tokens::blind_utxo;
-pub use send_tokens::transfer_asset;
+pub use send_tokens::{full_transfer_asset, transfer_asset};
 pub use validate_transaction::validate_transfer;
