@@ -10,7 +10,7 @@ use crate::{
 pub async fn accept_transfer(
     consignment: String,
     outpoint: OutPoint,
-    blinding_factor: u64,
+    blinding_factor: String,
 ) -> Result<String> {
     let accept_request = AcceptRequest {
         consignment,
@@ -21,14 +21,16 @@ pub async fn accept_transfer(
     let url = format!("{}accept", *NODE_SERVER_BASE_URL);
     let response = Request::post(&url)
         .body(serde_json::to_string(&accept_request)?)
-        .header("Content-Type", "application/json")
+        .header(
+            "Content-Type",
+            "application/x-www-form-urlencoded; charset=UTF-8",
+        )
         .send()
         .await
         .context("Problem at receiving request")?;
     log!("response");
-    // parse into generic JSON value
     let js: String = response
-        .json()
+        .text()
         .await
         .context("Problem at serdering servor response")?; //TODO: not working
     log!("json");
