@@ -11,7 +11,10 @@ pub async fn validate_transfer(consignment: String) -> Result<()> {
     let url = format!("{}validate", *NODE_SERVER_BASE_URL);
     let response = Request::post(&url)
         .body(serde_json::to_string(&validate_request)?)
-        .header("Content-Type", "application/json")
+        .header(
+            "Content-Type",
+            "application/x-www-form-urlencoded; charset=UTF-8",
+        )
         .send()
         .await?;
 
